# Aydin

Denoising, but chill...
It is the ultimate denoising software that comes as a CLI, an API 
and a GUI.

## Status
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)
[![codecov](https://codecov.io/gl/aydinorg/aydin/branch/master/graph/badge.svg?token=gV3UqFAg5U)](https://codecov.io/gl/aydinorg/aydin)
[![pipeline status](https://gitlab.com/aydinorg/aydin/badges/master/pipeline.svg)](https://gitlab.com/aydinorg/aydin/commits/master)

## Documentation

Aydin documentation can be found [here]().

## Installation

You can get the suitable aydin executable from PUT DOC DOWNLOAD PAGE HERE [here]() or you 
can do `pip install -e .`, for mac first need to do `brew install libomp`.

## How to run?

To run CLI for denoising:
```bash
aydin denoise path/to/noisyimage
```

To get help  on CLI usage:
```bash
aydin -h
```

## Recommended Environment

#### Linux

- Ubuntu 18.04+

#### Windows

- Windows 10

#### OSX

- Mojave 10.14.6+

## Contributing

Feel free to check our [contributing guideline](CONTRIBUTING.md) first and start 
discussing your new ideas and feedback with us through issues.
